@@ -11,6 +11,8 @@ if RUBY_VERSION == '1.8.7'
 end
 
 Puppet::Type.type(:apt_key).provide(:apt_key) do
+  desc 'apt-key provider for apt_key resource'
+
   confine    osfamily: :debian
   defaultfor osfamily: :debian
   commands   apt_key: 'apt-key'
@@ -119,7 +121,7 @@ Puppet::Type.type(:apt_key).provide(:apt_key) do
   def source_to_file(value)
     parsed_value = URI.parse(value)
     if parsed_value.scheme.nil?
-      raise("The file #{value} does not exist") unless File.exist?(value)
+      raise(_('The file %{_value} does not exist') % { _value: value }) unless File.exist?(value)
       # Because the tempfile method has to return a live object to prevent GC
       # of the underlying file from occuring too early, we also have to return
       # a file object here.  The caller can still call the #path method on the
@@ -139,9 +141,9 @@ Puppet::Type.type(:apt_key).provide(:apt_key) do
           key = open(parsed_value, http_basic_authentication: user_pass).read
         end
       rescue OpenURI::HTTPError, Net::FTPPermError => e
-        raise("#{e.message} for #{resource[:source]}")
+        raise(_('%{_e} for %{_resource}') % { _e: e.message, _resource: resource[:source] })
       rescue SocketError
-        raise("could not resolve #{resource[:source]}")
+        raise(_('could not resolve %{_resource}') % { _resource: resource[:source] })
       else
         tempfile(key)
       end
@@ -168,7 +170,7 @@ Puppet::Type.type(:apt_key).provide(:apt_key) do
           end
         end
         unless found_match
-          raise("The id in your manifest #{resource[:name]} and the fingerprint from content/source don't match. Check for an error in the id and content/source is legitimate.")
+          raise(_('The id in your manifest %{_resource} and the fingerprint from content/source don\'t match. Check for an error in the id and content/source is legitimate.') % { _resource: resource[:name] }) # rubocop:disable Metrics/LineLength
         end
       else
         warning('/usr/bin/gpg cannot be found for verification of the id.')
@@ -177,8 +179,31 @@ Puppet::Type.type(:apt_key).provide(:apt_key) do
     file
   end
 
+  # Update a key if it is expired
+  def update_expired_key
+    # Return without doing anything if refresh or expired is false
+    return unless resource[:refresh] == true && resource[:expired] == true
+
+    # Execute command to update key
+    command = []
+
+    unless resource[:source].nil? && resource[:content].nil?
+      raise(_('an unexpected condition occurred while trying to add the key: %{_resource}') % { _resource: resource[:id] })
+    end
+
+    # Breaking up the command like this is needed because it blows up
+    # if --recv-keys isn't the last argument.
+    command.push('adv', '--keyserver', resource[:server])
+    unless resource[:options].nil?
+      command.push('--keyserver-options', resource[:options])
+    end
+    command.push('--recv-keys', resource[:id])
+  end
+
   def exists?
-    @property_hash[:ensure] == :present
+    update_expired_key
+    # report expired keys as non-existing when refresh => true
+    @property_hash[:ensure] == :present && !(resource[:refresh] && @property_hash[:expired])
   end
 
   def create
@@ -199,7 +224,7 @@ Puppet::Type.type(:apt_key).provide(:apt_key) do
       command.push('add', key_file.path)
     # In case we really screwed up, better safe than sorry.
     else
-      raise("an unexpected condition occurred while trying to add the key: #{resource[:id]}")
+      raise(_('an unexpected condition occurred while trying to add the key: %{_resource}') % { _resource: resource[:id] })
     end
     apt_key(command)
     @property_hash[:ensure] = :present
@@ -215,7 +240,7 @@ Puppet::Type.type(:apt_key).provide(:apt_key) do
   end
 
   def read_only(_value)
-    raise('This is a read-only property.')
+    raise(_('This is a read-only property.'))
   end
 
   mk_resource_methods
